Package: shinyChatR
Type: Package
Title: R Shiny Chat Module
Version: 1.2.0
Authors@R: 
    c(person(given = "Julian",
             family = "Schmocker",
             role = c("aut", "cre", "cph"),
             email = "julian.schmocker@gmail.com"),
      person(given= "Ivo",
             family = "Kwee", 
             role = "aut",
             email = "ivo.kwee@gmail.com")
      )
Description: Provides an easy-to-use module for adding a chat to a Shiny app. Allows
    users to send messages and view messages from other users. 
    Messages can be stored in a database or a .rds file.
License: GPL (>= 3)
Encoding: UTF-8
Imports: data.table, DBI, purrr, R6, shiny
RoxygenNote: 7.3.1
VignetteBuilder: knitr
Suggests: covr, knitr, rmarkdown, RSQLite, testthat (>= 3.0.0)
Config/testthat/edition: 3
URL: https://github.com/julianschmocker/shinyChatR,
        https://julianschmocker.github.io/shinyChatR/
NeedsCompilation: no
Packaged: 2024-05-25 10:10:13 UTC; julianschmocker
Author: Julian Schmocker [aut, cre, cph],
  Ivo Kwee [aut]
Maintainer: Julian Schmocker <julian.schmocker@gmail.com>
Repository: CRAN
Date/Publication: 2024-05-25 10:30:02 UTC
Built: R 4.6.0; ; 2026-04-26 15:08:15 UTC; unix
